| Title: | Easily install and load the crisprVerse ecosystem for CRISPR gRNA design |
|---|---|
| Description: | The crisprVerse is a modular ecosystem of R packages developed for the design and manipulation of CRISPR guide RNAs (gRNAs). All packages share a common language and design principles. This package is designed to make it easy to install and load the crisprVerse packages in a single step. To learn more about the crisprVerse, visit <https://www.github.com/crisprVerse>. |
| Authors: | Jean-Philippe Fortin [aut, cre] |
| Maintainer: | Jean-Philippe Fortin <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.15.0 |
| Built: | 2026-05-31 06:27:30 UTC |
| Source: | https://github.com/bioc/crisprVerse |
List all crisprVerse dependencies
crisprVerse_deps(recursive = FALSE)crisprVerse_deps(recursive = FALSE)
recursive |
If |
A data.frame describing crisprVerse dependencies
if (interactive()){ crisprVerse_deps() }if (interactive()){ crisprVerse_deps() }
List all packages in the crisprVerse
crisprVerse_packages(include_self = TRUE)crisprVerse_packages(include_self = TRUE)
include_self |
Include crisprVerse in the list? |
A character vector of packages in the crisprVerse
crisprVerse_packages()crisprVerse_packages()
This will check to see if all crisprVerse packages (and optionally, their dependencies) are up-to-date, and will install after an interactive confirmation.
crisprVerse_update(recursive = FALSE)crisprVerse_update(recursive = FALSE)
recursive |
If |
Print messages to console as a side effect.
if (interactive()){ crisprVerse_update() }if (interactive()){ crisprVerse_update() }